@@ -3,7 +3,11 @@ from __future__ import print_function
 
 __all__ = ["ScalarString", "PreservedScalarString"]
 
-from .compat import text_type
+try:
+    from .compat import text_type
+except (ImportError, ValueError):  # for Jython
+    from ruamel.yaml.compat import text_type
+
 
 
 class ScalarString(text_type):
